@@ -695,6 +695,8 @@ retro_core_destructor (RetroCore *self)
   if (internal->media_uris != NULL)
     g_strfreev (internal->media_uris);
 
+  g_object_unref (internal->module);
+
   g_free (self->environment_internal);
 }
 
@@ -1044,7 +1046,16 @@ retro_core_set_memory (RetroCore       *self,
   retro_core_pop_cb_data ();
 
   g_return_if_fail (memory_region != NULL);
-  g_return_if_fail (memory_region_size == length);
+  g_return_if_fail (memory_region_size >= length);
+
+  if (memory_region_size != length)
+    g_debug ("%s expects %"G_GSIZE_FORMAT" bytes for memory region %d: %d bytes"
+             " were passed. The excess will be filled with zeros.",
+             retro_core_get_name (self),
+             memory_region_size,
+             id,
+             length);
 
   memcpy (memory_region, data, length);
+  memset (memory_region + length, 0, memory_region_size - length);
 }
