@@ -1,4 +1,4 @@
-// This file is part of retro-gtk. License: GPLv3
+// This file is part of retro-gtk. License: GPL-3.0+.
 
 #include "retro-gtk-internal.h"
 #include "libretro-environment.h"
@@ -54,6 +54,7 @@ on_log (guint level, const gchar *format, ...)
 {
   RetroCore *self;
   RetroSystemInfo info = { 0 };
+  const gchar *log_domain;
   GLogLevelFlags log_level;
   gchar *message;
   va_list args;
@@ -91,9 +92,8 @@ on_log (guint level, const gchar *format, ...)
   va_start (args, format);
   message = g_strdup_vprintf (format, args);
 
-  retro_core_get_system_info (self, &info);
-
-  g_signal_emit_by_name (self, "log", info.library_name, log_level, message);
+  log_domain = retro_core_get_name (self);
+  g_signal_emit_by_name (self, "log", log_domain, log_level, message);
 
   g_free (message);
 }
@@ -218,8 +218,7 @@ static gboolean
 set_disk_control_interface (RetroCore                *self,
                             RetroDiskControlCallback *callback)
 {
-  // TODO Split this in two lines.
-  retro_core_set_disk_control_interface (self, RETRO_DISK_CONTROL (retro_disk_control_new (self, callback)));
+  RETRO_CORE_ENVIRONMENT_INTERNAL (self)->disk_control_callback = callback;
 
   return TRUE;
 }
@@ -549,10 +548,13 @@ on_input_state (guint port,
 void
 retro_core_set_environment_interface (RetroCore *self)
 {
+  RetroCoreEnvironmentInternal *internal;
   RetroModule *module;
   RetroCallbackSetter set_environment;
 
-  module = self->module;
+  internal = RETRO_CORE_ENVIRONMENT_INTERNAL (self);
+
+  module = internal->module;
   set_environment = retro_module_get_set_environment (module);
 
   retro_core_push_cb_data (self);
@@ -564,6 +566,7 @@ retro_core_set_environment_interface (RetroCore *self)
 void
 retro_core_set_callbacks (RetroCore *self)
 {
+  RetroCoreEnvironmentInternal *internal;
   RetroModule *module;
   RetroCallbackSetter set_video_refresh;
   RetroCallbackSetter set_audio_sample;
@@ -571,7 +574,9 @@ retro_core_set_callbacks (RetroCore *self)
   RetroCallbackSetter set_input_poll;
   RetroCallbackSetter set_input_state;
 
-  module = self->module;
+  internal = RETRO_CORE_ENVIRONMENT_INTERNAL (self);
+
+  module = internal->module;
   set_video_refresh = retro_module_get_set_video_refresh (module);
   set_audio_sample = retro_module_get_set_audio_sample (module);
   set_audio_sample_batch = retro_module_get_set_audio_sample_batch (module);
